Gitweb:     
http://git.kernel.org/git/?p=linux/kernel/git/torvalds/linux-2.6.git;a=commit;h=9e7bbccd0290e720e0874443932869c55f63d5a8
Commit:     9e7bbccd0290e720e0874443932869c55f63d5a8
Parent:     ac3c8141f62f357169980ec21b7be6d29964a394
Author:     Greg Kroah-Hartman <[EMAIL PROTECTED]>
AuthorDate: Mon Dec 17 23:05:35 2007 -0700
Committer:  Greg Kroah-Hartman <[EMAIL PROTECTED]>
CommitDate: Thu Jan 24 20:40:38 2008 -0800

    Kobject: remove kobject_add() as no one uses it anymore
    
    The old kobject_add() function is on longer in use, so let us remove it
    from the public scope (kset mess in the kobject.c file still uses it,
    but that can be cleaned up later very simply.)
    
    Cc: Kay Sievers <[EMAIL PROTECTED]>
    Signed-off-by: Greg Kroah-Hartman <[EMAIL PROTECTED]>
---
 include/linux/kobject.h |    1 -
 lib/kobject.c           |   22 ++++++++--------------
 2 files changed, 8 insertions(+), 15 deletions(-)

diff --git a/include/linux/kobject.h b/include/linux/kobject.h
index bb68684..8b0aa71 100644
--- a/include/linux/kobject.h
+++ b/include/linux/kobject.h
@@ -80,7 +80,6 @@ static inline const char * kobject_name(const struct kobject 
* kobj)
 
 extern void kobject_init(struct kobject *);
 extern void kobject_init_ng(struct kobject *kobj, struct kobj_type *ktype);
-extern int __must_check kobject_add(struct kobject *);
 extern int __must_check kobject_add_ng(struct kobject *kobj,
                                       struct kobject *parent,
                                       const char *fmt, ...);
diff --git a/lib/kobject.c b/lib/kobject.c
index 493e991..d04789f 100644
--- a/lib/kobject.c
+++ b/lib/kobject.c
@@ -144,7 +144,7 @@ void kobject_init(struct kobject * kobj)
  *     Remove the kobject from the kset list and decrement
  *     its parent's refcount.
  *     This is separated out, so we can use it in both 
  *     kobject_del() and kobject_add() on error.
  */
 
 static void unlink(struct kobject * kobj)
@@ -161,12 +161,7 @@ static void unlink(struct kobject * kobj)
        kobject_put(parent);
 }
 
-/**
- *     kobject_add - add an object to the hierarchy.
- *     @kobj:  object.
- */
-
-int kobject_add(struct kobject * kobj)
+static int kobject_add_internal(struct kobject *kobj)
 {
        int error = 0;
        struct kobject * parent;
@@ -215,13 +210,13 @@ int kobject_add(struct kobject * kobj)
 
                /* be noisy on error issues */
                if (error == -EEXIST)
-                       printk(KERN_ERR "kobject_add failed for %s with "
+                       printk(KERN_ERR "%s failed for %s with "
                               "-EEXIST, don't try to register things with "
                               "the same name in the same directory.\n",
-                              kobject_name(kobj));
+                              __FUNCTION__, kobject_name(kobj));
                else
-                       printk(KERN_ERR "kobject_add failed for %s (%d)\n",
-                              kobject_name(kobj), error);
+                       printk(KERN_ERR "%s failed for %s (%d)\n",
+                              __FUNCTION__, kobject_name(kobj), error);
                dump_stack();
        }
 
@@ -351,7 +346,7 @@ static int kobject_add_varg(struct kobject *kobj, struct 
kobject *parent,
                return retval;
        }
        kobj->parent = parent;
-       return kobject_add(kobj);
+       return kobject_add_internal(kobj);
 }
 
 /**
@@ -742,7 +737,7 @@ struct sysfs_ops kobj_sysfs_ops = {
 
 int kset_add(struct kset * k)
 {
-       return kobject_add(&k->kobj);
+       return kobject_add_internal(&k->kobj);
 }
 
 
@@ -897,7 +892,6 @@ EXPORT_SYMBOL(kobject_register);
 EXPORT_SYMBOL(kobject_unregister);
 EXPORT_SYMBOL(kobject_get);
 EXPORT_SYMBOL(kobject_put);
-EXPORT_SYMBOL(kobject_add);
 EXPORT_SYMBOL(kobject_del);
 
 EXPORT_SYMBOL(kset_register);
-
@@ -144,7 +144,7 @@ void kobject_init(struct kobject * kobj)
  *     its parent's refcount.
  *     This is separated out, so we can use it in both 
- *     kobject_del() and kobject_add() on error.
+ *     kobject_del() and kobject_add_internal() on error.
  */
 
To unsubscribe from this list: send the line "unsubscribe git-commits-head" in
the body of a message to [EMAIL PROTECTED]
More majordomo info at  http://vger.kernel.org/majordomo-info.html

Reply via email to